#!/bin/bash

# Run this script with optional args:
# 1 - username for the service to run as (defaults to www-data)
# 2 - the name for the service (defaults to greenstone3) - change this eg if you want to run two greenstone services
if [ -d "/etc/systemd/system/" ] ; then

    if [ "x$GSDL3SRCHOME" = "x" ] ; then
	cd .. && source ./gs3-setup.sh && cd service.d
    fi

    gsdl_service_username=${1-www-data}
    gsdl_service_name=${2-greenstone3}
    
    echo ""
    
    echo "****"
    echo "* Generating $gsdl_service_name.service from greenstone3.service.in"
    echo "* using user $gsdl_service_username"
    echo "****"
    cat greenstone3.service.in \
	| sed "s%@GSDL3SRCHOME@%$GSDL3SRCHOME%g" \
	| sed "s%@GSDL_SERVICE_USERNAME@%$gsdl_service_username%g" \
	      > $gsdl_service_name.service
     
    echo "****"
    echo "* Copying $gsdl_service_name.service to /etc/systemd/system/"
    echo "****"
    sudo /bin/cp $gsdl_service_name.service /etc/systemd/system/.

    echo ""
    echo "----"
    echo "General info:"
    echo "  In the event of the service being updated, you will most likely need to run:"
    echo "    sudo systemctl daemon-reload"
    echo ""
    echo "  To enable this service to be run at boot-up time, run:"
    echo "    sudo systemctl enable $gsdl_service_name"
    echo "----"
    
else
    echo "Error: Failed to find '/etc/systemd/system'" >&2
    echo "This install script was developed on a Debian system." >&2
    echo "It looks like your Linux Distribution uses a different directory structure for services" >&2

    exit 1
fi  

